@@ -1,10 +1,10 @@
 /******************************************************************************
  * SIENA: Simulation Investigation for Empirical Network Analysis
- * 
+ *
  * Web: http://www.stats.ox.ac.uk/~snijders/siena/
- * 
+ *
  * File: NetworkLongitudinalData.h
- * 
+ *
  * Description: This file contains the definition of the
  * NetworkLongitudinalData class.
  *****************************************************************************/
@@ -39,45 +39,53 @@ public:
 		const ActorSet * pReceivers,
 		int observationCount);
 	virtual ~NetworkLongitudinalData();
-	
+
 	const ActorSet * pSenders() const;
 	const ActorSet * pReceivers() const;
-	Network * pNetwork(int observation);
-	Network * pStructuralTieNetwork(int observation);
-	Network * pMissingTieNetwork(int observation);
 	const Network * pNetwork(int observation) const;
 	const Network * pStructuralTieNetwork(int observation) const;
 	const Network * pMissingTieNetwork(int observation) const;
-	
+
 	int tieValue(int i, int j, int observation) const;
+	void tieValue(int i, int j, int observation, int value);
 	bool missing(int i, int j, int observation) const;
+	void missing(int i, int j, int observation, bool flag);
+	bool structural(int i, int j, int observation) const;
+	void structural(int i, int j, int observation, bool flag);
 	int structuralTieCount(int actor, int observation) const;
-	
+
+	void calculateProperties();
+
 	void maxDegree(int degree);
 	int maxDegree() const;
-	
-	virtual DependentVariable * createVariable(
-		EpochSimulation * pSimulation);
-	
+	double averageInDegree() const;
+	double averageOutDegree() const;
+
 private:
 	// The set of actors receiving the ties of the network
 	const ActorSet * lpReceivers;
-	
+
 	// A collection of networks, one per each observation
 	Network ** lnetworks;
-	
+
 	// Structural tie indicators per each observation stored as
 	// binary networks for efficiency
-	
+
 	Network ** lstructuralTieNetworks;
-	
+
 	// Structural tie indicators per each observation stored as
 	// binary networks for efficiency
-	
+
 	Network ** lmissingTieNetworks;
-	
+
 	// The maximum permitted out-degree of an actor. Infinity by default.
 	int lmaxDegree;
+
+	// The average in-degree over all receivers and observations
+	double laverageInDegree;
+
+	// The average out-degree over all senders and observations
+	double laverageOutDegree;
 };
 
 }
