@@ -31,6 +31,8 @@ class Model;
 class ActorSet;
 class EffectInfo;
 class SimulationActorSet;
+class State;
+class Cache;
 
 
 // ----------------------------------------------------------------------------
@@ -64,6 +66,8 @@ public:
     double score(const EffectInfo * pEffect) const;
     void score(const EffectInfo * pEffect, double value);
 
+    Cache * pCache() const;
+
 private:
     void runStep();
     void calculateRates();
@@ -110,7 +114,7 @@ private:
     const EventSet * lpEvents;
 
     // An iterator to the next event still to be processed.
-    EventSet::iterator lnextEvent;
+    EventSet::const_iterator lnextEvent;
 
     // Target amount of change for this period if we are using conditional simulation
     int ltargetChange;
@@ -118,15 +122,13 @@ private:
     // The dependent variable the simulation is conditioned upon
     DependentVariable * lpConditioningVariable;
 
-    // Observed values of statistics in this simulation: one value for each
-    // selected effect, including the rate effects, except basic rate for
-    // conditioning variable, if any.
-    vector<double> lsimulatedStatistics;
-
     // Values of scores in this simulation: one for each selected effect,
     // including the rate effects, but excluding the basic rate effect.
 
     map<const EffectInfo *, double> lscores;
+
+    State * lpState;
+    Cache * lpCache;
 };
 
 }
