@@ -13,42 +13,49 @@
 #define ALLEFFECTS_H_
 
 #include "AverageAlterEffect.h"
-#include "AverageSimilarityEffect.h"
+#include "AverageReciprocatedAlterEffect.h"
 #include "BalanceEffect.h"
-#include "BehaviorMainBehaviorEffect.h"
 #include "BetweennessEffect.h"
-#include "ChangingCovariateMainBehaviorEffect.h"
-#include "ConstantCovariateMainBehaviorEffect.h"
 #include "CovariateAlterEffect.h"
 #include "CovariateEgoAlterEffect.h"
 #include "CovariateEgoEffect.h"
 #include "CovariateIndirectTiesEffect.h"
 #include "CovariateSimilarityEffect.h"
+#include "DenseTriadsBehaviorEffect.h"
 #include "DenseTriadsEffect.h"
+#include "DenseTriadsSimilarityEffect.h"
 #include "DensityEffect.h"
 #include "DistanceTwoEffect.h"
 #include "DyadicCovariateMainEffect.h"
 #include "DyadicCovariateReciprocityEffect.h"
 #include "FourCyclesEffect.h"
+#include "HigherCovariateEffect.h"
 #include "IndegreeEffect.h"
 #include "IndegreeActivityEffect.h"
 #include "IndegreePopularityEffect.h"
 #include "InInDegreeAssortativityEffect.h"
 #include "InOutDegreeAssortativityEffect.h"
+#include "InteractionCovariateEffect.h"
 #include "InverseOutdegreeEffect.h"
 #include "InverseSquaredOutdegreeEffect.h"
+#include "IsolateEffect.h"
 #include "LinearShapeEffect.h"
+#include "MainCovariateEffect.h"
+#include "NetworkInteractionEffect.h"
 #include "OutdegreeEffect.h"
 #include "OutdegreeActivityEffect.h"
 #include "OutdegreeActivitySqrtEffect.h"
 #include "OutdegreePopularityEffect.h"
 #include "OutInDegreeAssortativityEffect.h"
 #include "OutOutDegreeAssortativityEffect.h"
+#include "PopularityAlterEffect.h"
 #include "QuadraticShapeEffect.h"
+#include "ReciprocalDegreeBehaviorEffect.h"
+#include "ReciprocatedSimilarityEffect.h"
 #include "ReciprocityEffect.h"
 #include "SameCovariateEffect.h"
+#include "SimilarityEffect.h"
 #include "ThreeCyclesEffect.h"
-#include "TotalSimilarityEffect.h"
 #include "TransitiveMediatedTripletsEffect.h"
 #include "TransitiveTiesEffect.h"
 #include "TransitiveTriadsEffect.h"
