@@ -37,7 +37,7 @@ public:
 	virtual double calculateContribution(int alter) const;
 
 protected:
-	virtual double statistic(const Network * pSummationTieNetwork) const;
+	virtual double tieStatistic(int alter);
 
 private:
 	AlterFunction * lpFunction;
